@@ -23,10 +23,11 @@ import (
 	"github.com/go-kit/log"
 	"github.com/go-kit/log/level"
 	"github.com/prometheus/client_golang/prometheus"
+	"github.com/prometheus/client_golang/prometheus/collectors/version"
 	"github.com/prometheus/client_golang/prometheus/promhttp"
 	"github.com/prometheus/common/promlog"
 	"github.com/prometheus/common/promlog/flag"
-	"github.com/prometheus/common/version"
+	common_version "github.com/prometheus/common/version"
 
 	"github.com/prometheus/exporter-toolkit/web"
 	"github.com/prometheus/exporter-toolkit/web/kingpinflag"
@@ -67,7 +68,7 @@ func parseUnixSocketAddress(address string) (string, string, error) {
 	addressPartsLength := len(addressParts)
 
 	if addressPartsLength > 3 || addressPartsLength < 1 {
-		return "", "", fmt.Errorf("address for unix domain socket has wrong format")
+		return "", "", errors.New("address for unix domain socket has wrong format")
 	}
 
 	unixSocketPath := addressParts[1]
@@ -103,7 +104,7 @@ func main() {
 	// convert deprecated flags to new format
 	for i, arg := range os.Args {
 		if strings.HasPrefix(arg, "-") && !strings.HasPrefix(arg, "--") && len(arg) > 2 {
-			newArg := fmt.Sprintf("-%s", arg)
+			newArg := "-" + arg
 			fmt.Printf("the flag format is deprecated and will be removed in a future release, please use the new format: %s\n", newArg)
 			os.Args[i] = newArg
 		}
@@ -112,13 +113,16 @@ func main() {
 	promlogConfig := &promlog.Config{}
 
 	flag.AddFlags(kingpin.CommandLine, promlogConfig)
-	kingpin.Version(version.Print(exporterName))
+	kingpin.Version(common_version.Print(exporterName))
 	kingpin.HelpFlag.Short('h')
+
+	addMissingEnvironmentFlags(kingpin.CommandLine)
+
 	kingpin.Parse()
 	logger := promlog.New(promlogConfig)
 
-	level.Info(logger).Log("msg", "Starting nginx-prometheus-exporter", "version", version.Info())
-	level.Info(logger).Log("msg", "Build context", "build_context", version.BuildContext())
+	level.Info(logger).Log("msg", "Starting nginx-prometheus-exporter", "version", common_version.Info())
+	level.Info(logger).Log("msg", "Build context", "build_context", common_version.BuildContext())
 
 	prometheus.MustRegister(version.NewCollector(exporterName))
 
@@ -176,7 +180,7 @@ func main() {
 			Name:        "NGINX Prometheus Exporter",
 			Description: "Prometheus Exporter for NGINX and NGINX Plus",
 			HeaderColor: "#039900",
-			Version:     version.Info(),
+			Version:     common_version.Info(),
 			Links: []web.LandingLinks{
 				{
 					Address: *metricsPath,
@@ -233,7 +237,7 @@ func registerCollector(logger log.Logger, transport *http.Transport,
 		addr = "http://unix" + requestPath
 	}
 
-	userAgent := fmt.Sprintf("NGINX-Prometheus-Exporter/v%v", version.Version)
+	userAgent := fmt.Sprintf("NGINX-Prometheus-Exporter/v%v", common_version.Version)
 
 	httpClient := &http.Client{
 		Timeout: *timeout,
@@ -258,8 +262,8 @@ func registerCollector(logger log.Logger, transport *http.Transport,
 }
 
 type userAgentRoundTripper struct {
-	agent string
 	rt    http.RoundTripper
+	agent string
 }
 
 func (rt *userAgentRoundTripper) RoundTrip(req *http.Request) (*http.Response, error) {
@@ -281,3 +285,24 @@ func cloneRequest(req *http.Request) *http.Request {
 	}
 	return r
 }
+
+// addMissingEnvironmentFlags sets Envar on any flag which has
+// the "web." prefix which doesn't already have an Envar set
+func addMissingEnvironmentFlags(ka *kingpin.Application) {
+	for _, f := range ka.Model().FlagGroupModel.Flags {
+		if strings.HasPrefix(f.Name, "web.") && f.Envar == "" {
+			flag := ka.GetFlag(f.Name)
+			if flag != nil {
+				flag.Envar(convertFlagToEnvar(strings.TrimPrefix(f.Name, "web.")))
+			}
+		}
+	}
+}
+
+func convertFlagToEnvar(f string) string {
+	env := strings.ToUpper(f)
+	for _, s := range []string{"-", "."} {
+		env = strings.ReplaceAll(env, s, "_")
+	}
+	return env
+}
